aboutsummaryrefslogtreecommitdiff
path: root/ports/cryptopp
diff options
context:
space:
mode:
authorRobert Schumacher <roschuma@microsoft.com>2020-02-04 15:50:10 -0800
committerRobert Schumacher <roschuma@microsoft.com>2020-02-04 15:50:10 -0800
commit6f66ad14fe9da11d4bf50f5b25b4da86ed971c53 (patch)
tree0f5dbcd1719cd6a8e486c4058cfefd607d58aa6c /ports/cryptopp
parentd502f061bb3ee0258d6453acbf258b9e5d93d564 (diff)
parentd808514c9df44bb97d6eccff952bfe8ec4e156f7 (diff)
downloadvcpkg-6f66ad14fe9da11d4bf50f5b25b4da86ed971c53.tar.gz
vcpkg-6f66ad14fe9da11d4bf50f5b25b4da86ed971c53.zip
Merge remote-tracking branch 'origin/master' into HEAD
Diffstat (limited to 'ports/cryptopp')
-rw-r--r--ports/cryptopp/CONTROL2
-rw-r--r--ports/cryptopp/portfile.cmake6
2 files changed, 5 insertions, 3 deletions
diff --git a/ports/cryptopp/CONTROL b/ports/cryptopp/CONTROL
index 23a7bb456..9c11e1906 100644
--- a/ports/cryptopp/CONTROL
+++ b/ports/cryptopp/CONTROL
@@ -1,4 +1,4 @@
Source: cryptopp
-Version: 8.2.0
+Version: 8.2.0-1
Homepage: https://github.com/weidai11/cryptopp
Description: Crypto++ is a free C++ class library of cryptographic schemes.
diff --git a/ports/cryptopp/portfile.cmake b/ports/cryptopp/portfile.cmake
index d744deccd..36c747884 100644
--- a/ports/cryptopp/portfile.cmake
+++ b/ports/cryptopp/portfile.cmake
@@ -24,8 +24,10 @@ vcpkg_from_github(
file(COPY ${CMAKE_SOURCE_PATH}/cryptopp-config.cmake DESTINATION ${SOURCE_PATH})
file(COPY ${CMAKE_SOURCE_PATH}/CMakeLists.txt DESTINATION ${SOURCE_PATH})
-# disable assembly on OSX to fix broken build
-if (VCPKG_CMAKE_SYSTEM_NAME STREQUAL "Darwin")
+# disable assembly on OSX and ARM Windows to fix broken build
+if (VCPKG_TARGET_IS_OSX)
+ set(CRYPTOPP_DISABLE_ASM "ON")
+elseif (VCPKG_TARGET_IS_WINDOWS AND VCPKG_TARGET_ARCHITECTURE MATCHES "^arm")
set(CRYPTOPP_DISABLE_ASM "ON")
else()
set(CRYPTOPP_DISABLE_ASM "OFF")